;--------------------------------------------------------------------------------------------------
;----------------------------------------routines I2C----------------------------------------------
;-----------------------------------Michael Vincent I2C Routines-----------------------------------
;----------------------Slightly modified by Lucien Dos Santos Farret(LuciDs)-----------------------
;	11/08/12
;	Routines:			I2C_SendStart
;						I2C_SendStop
;						I2C_WriteByte
;						I2C_ReadByte

;---Constants:
						I2C_SDA_LOW    	=	$01
						I2C_SCL_LOW   	= 	$02
						
						I2C_WRFLAG		=	$00
						I2C_RDFLAG		=	$01

;//////////////////////////////////////////////////////////////////////////////////////////////////
;///////////////////////////////////	I2C_SendStart			///////////////////////////////////
;	>	Send a start condition on the link
;	In:			Nothing.
;	Out:		Nothing.
;	Destroys:	A
I2C_SendStart:
						xor			a
						out			(0),		a
						ld			a, 			I2C_sda_low
						out			(0), 		a
						ld			a, 			I2C_sda_low | I2C_scl_low
						out			(0), 		a
						
						ret
						
;//////////////////////////////////////////////////////////////////////////////////////////////////
;///////////////////////////////////	I2C_SendStop			///////////////////////////////////
;	>	Send a stop condition on the link
;	In:			Nothing.
;	Out:		Nothing.
;	Destroys:	Nothing.
I2C_SendStop:
						push		af
						
						ld			a, 			I2C_sda_low | I2C_scl_low
						out			(0), 		a
						ld			a, 			I2C_sda_low
						out			(0), 		a
						xor			a
						out			(0),		a
						
						pop			af
						
						ret

;//////////////////////////////////////////////////////////////////////////////////////////////////
;///////////////////////////////////	I2C_WriteByte			///////////////////////////////////
;	>	Write one byte on the link
;	In:			C :			The byte transmitted
;	Out:		cf:			set:	No Acknowledge
;							reset:  Acknowledge
;	Destroys:	A,F,B	
I2C_WriteByte:
						ld				b, 		8
I2C_WriteByte_Loop:
							rlc			c
							ccf
							ld			a, 		I2C_SCL_LOW >> 1
							rla
							out			(0), 	a
							xor			I2C_SCL_LOW
							out			(0),	a
							xor			I2C_SCL_LOW
							out			(0), 	a
							djnz		I2C_WriteByte_Loop
							
						xor			a
						out			(0), 	a
						in			a, 		(0)
						rra
						jr			c,		I2C_SendStop
						ld			a, 		I2C_SCL_LOW
						out			(0), 	a
						ret
						
						
;//////////////////////////////////////////////////////////////////////////////////////////////////
;///////////////////////////////////	I2C_ReadByte			///////////////////////////////////
;	>	Reads one byte through the link
;	In:			cf:			Set:	Send a ACK after reading
;							Reset:	Send a NACK	after reading
;	Out:		C :			The byte recieved
;	Destroys:	A,F,B,C
I2C_ReadByte:
						push		af
						ld			b,		8
I2C_ReadByte_Loop:
							ld				a,		I2C_SCL_LOW
							out				(0), 	a
							xor				a
							out				(0), 	a
							in				a, 		(0)
							rra
							rl				c
							djnz			I2C_ReadByte_Loop
						
						pop			af
						ld			a,		I2C_SCL_LOW >> 1
						rla
						out			(0), 	a
						xor			I2C_SCL_LOW
						out			(0),	a
						xor			I2C_SCL_LOW
						out			(0),	a
						
						ret
	
;--------------------------------------------------------------------------------------------------
